FlowControlSnapshot

Struct FlowControlSnapshot 

pub struct FlowControlSnapshot {
    pub queues: QueueDepthBytes,
    pub rates: RateWindowBps,
    pub latency: LatencyWindowMs,
    pub serviced_input_bytes: u64,
    pub serviced_output_bytes: u64,
    pub output_hard_cap_duration_ms: u64,
}
Deterministic snapshot consumed by the policy evaluator.

Fields

queues: QueueDepthBytes

Current queue depths.

rates: RateWindowBps

Sliding-window rates.

latency: LatencyWindowMs

Sliding-window latency summary.

serviced_input_bytes: u64

Bytes serviced from input lane in the fairness window.

serviced_output_bytes: u64

Bytes serviced from output lane in the fairness window.

output_hard_cap_duration_ms: u64

How long output queue has continuously stayed at hard cap.

Implementations

Source

impl FlowControlSnapshot

pub fn fairness_index(self) -> f64

Jain fairness index over serviced input/output bytes in this window.