pub struct FlowControlSnapshot {
pub queues: QueueDepthBytes,
pub rates: RateWindowBps,
pub latency: LatencyWindowMs,
pub serviced_input_bytes: u64,
pub serviced_output_bytes: u64,
pub output_hard_cap_duration_ms: u64,
}Expand description
Deterministic snapshot consumed by the policy evaluator.
Fields
queues: QueueDepthBytesCurrent queue depths.
rates: RateWindowBpsSliding-window rates.
latency: LatencyWindowMsSliding-window latency summary.
serviced_input_bytes: u64Bytes serviced from input lane in the fairness window.
serviced_output_bytes: u64Bytes serviced from output lane in the fairness window.
output_hard_cap_duration_ms: u64How long output queue has continuously stayed at hard cap.
Implementations
Sourceimpl FlowControlSnapshot
impl FlowControlSnapshot
Sourcepub fn fairness_index(self) -> f64
pub fn fairness_index(self) -> f64
Jain fairness index over serviced input/output bytes in this window.