pub enum TerminalQuery {
DeviceStatus,
CursorPosition,
ExtendedCursorPosition,
PrimaryDeviceAttributes,
SecondaryDeviceAttributes,
DecModeReport {
mode: u16,
},
}Expand description
Decoded terminal query extracted from an escape sequence.
Variants
DeviceStatus
DSR operating-status query (CSI 5 n).
CursorPosition
DSR cursor-position query (CSI 6 n).
ExtendedCursorPosition
DECXCPR cursor-position query (CSI ? 6 n).
PrimaryDeviceAttributes
DA1 primary device attributes (CSI c / CSI 0 c).
SecondaryDeviceAttributes
DA2 secondary device attributes (CSI > c / CSI >0 c).
DecModeReport
DECRPM mode status query (CSI ? Ps $ p).
Implementations
Sourceimpl TerminalQuery
impl TerminalQuery
Sourcepub fn parse_escape(seq: &[u8]) -> Option<Self>
pub fn parse_escape(seq: &[u8]) -> Option<Self>
Attempt to decode a query from a raw escape payload.
The sequence must be complete and start with ESC [.